@@ -16,14 +16,23 @@ def main():
                       default=69)
     parser.add_option('-f',
                       '--filename',
-                      help='filename to fetch')
+                      help='filename to fetch (deprecated, use download)')
+    parser.add_option('-D',
+                      '--download',
+                      help='filename to download')
+    parser.add_option('-u',
+                      '--upload',
+                      help='filename to upload')
     parser.add_option('-b',
-                      '--blocksize',
+                      '--blksize',
                       help='udp packet size to use (default: 512)',
                       default=512)
     parser.add_option('-o',
                       '--output',
                       help='output file (default: same as requested filename)')
+    parser.add_option('-i',
+                      '--input',
+                      help='input file (default: same as upload filename)')
     parser.add_option('-d',
                       '--debug',
                       action='store_true',
@@ -40,7 +49,10 @@ def main():
                       default=False,
                       help="ask client to send tsize option in download")
     options, args = parser.parse_args()
-    if not options.host or not options.filename:
+    # Handle legacy --filename argument.
+    if options.filename:
+        options.download = options.filename
+    if not options.host or (not options.download and not options.upload):
         sys.stderr.write("Both the --host and --filename options "
                          "are required.\n")
         parser.print_help()
@@ -52,9 +64,6 @@ def main():
         parser.print_help()
         sys.exit(1)
 
-    if not options.output:
-        options.output = os.path.basename(options.filename)
-
     class Progress(object):
         def __init__(self, out):
             self.progress = 0
@@ -62,7 +71,7 @@ def main():
         def progresshook(self, pkt):
             if isinstance(pkt, tftpy.TftpPacketDAT):
                 self.progress += len(pkt.data)
-                self.out("Downloaded %d bytes" % self.progress)
+                self.out("Transferred %d bytes" % self.progress)
             elif isinstance(pkt, tftpy.TftpPacketOACK):
                 self.out("Received OACK, options are: %s" % pkt.options)
         
@@ -73,21 +82,35 @@ def main():
     else:
         tftpy.setLogLevel(logging.INFO)
 
-    progresshook = Progress(tftpy.logger.info).progresshook
+    progresshook = Progress(tftpy.log.info).progresshook
 
     tftp_options = {}
-    if options.blocksize:
-        tftp_options['blksize'] = int(options.blocksize)
+    if options.blksize:
+        tftp_options['blksize'] = int(options.blksize)
     if options.tsize:
-        tftp_options['tsize'] = 1
+        tftp_options['tsize'] = 0
 
     tclient = tftpy.TftpClient(options.host,
                                int(options.port),
                                tftp_options)
-
-    tclient.download(options.filename,
-                     options.output,
-                     progresshook)
+    try:
+        if options.download:
+            if not options.output:
+                options.output = os.path.basename(options.download)
+            tclient.download(options.download,
+                            options.output,
+                            progresshook)
+        elif options.upload:
+            if not options.input:
+                options.input = os.path.basename(options.upload)
+            tclient.upload(options.upload,
+                        options.input,
+                        progresshook)
+    except tftpy.TftpException, err:
+        sys.stderr.write("%s\n" % str(err))
+        sys.exit(1)
+    except KeyboardInterrupt:
+        pass
 
 if __name__ == '__main__':
     main()
