@@ -19,9 +19,9 @@ class TftpPacketFactory(object):
         """This method is used to parse an existing datagram into its
         corresponding TftpPacket object. The buffer is the raw bytes off of
         the network."""
-        logger.debug("parsing a %d byte packet" % len(buffer))
+        log.debug("parsing a %d byte packet" % len(buffer))
         (opcode,) = struct.unpack("!H", buffer[:2])
-        logger.debug("opcode is %d" % opcode)
+        log.debug("opcode is %d" % opcode)
         packet = self.__create(opcode)
         packet.buffer = buffer
         return packet.decode()
@@ -29,10 +29,9 @@ class TftpPacketFactory(object):
     def __create(self, opcode):
         """This method returns the appropriate class object corresponding to
         the passed opcode."""
-        tftpassert(self.classes.has_key(opcode), 
+        tftpassert(self.classes.has_key(opcode),
                    "Unsupported opcode: %d" % opcode)
 
         packet = self.classes[opcode]()
 
-        logger.debug("packet is %s" % packet)
         return packet
